@@ -22,7 +22,7 @@
 #' library(MPDiR) # contains the Vernier data
 #' data(Vernier) # ?Venier for the reference
 #' fit <- quickpsy(Vernier, Phaseshift, NumUpward, N,
-#'                 grouping = .(Direction, WaveForm, TempFreq), B = 10)
+#'                 grouping = .(Direction, WaveForm, TempFreq), B = 5)
 #'
 #' plotcurves_(fit, xpanel = 'Direction')
 #' plotcurves_(fit, color = 'Direction')
@@ -34,7 +34,7 @@ plotcurves_ <- function(qp, panel = NULL, xpanel = NULL, ypanel = NULL,
                thresholds = TRUE, ci = TRUE) {
 
   if (!('thresholds' %in% names(qp))) thresholds <- FALSE
-  if (!('thresholdsci' %in% names(qp))) ci <- FALSE
+  if (!('threinf' %in% names(qp$thresholds))) ci <- FALSE
 
   if (is.logical(qp$guess)) qp$guess <- 0
   if (is.logical(qp$lapses)) qp$lapses <- 0
@@ -120,7 +120,7 @@ plotcurves_ <- function(qp, panel = NULL, xpanel = NULL, ypanel = NULL,
    if (thresholds) p <- p + geom_linerange(data = qp$thresholds,
                         aes_string(x = 'thre', ymin = qp$guess,
                             ymax = qp$thresholds$prob))
-   if (ci) p <- p + geom_errorbarh(data = qp$thresholdsci,
+   if (ci) p <- p + geom_errorbarh(data = qp$thresholds,
                     height = .03, aes_string(x = 'threinf', xmin = 'threinf',
                     xmax = 'thresup', y = qp$thresholds$prob))
   }
@@ -148,8 +148,7 @@ plotcurves_ <- function(qp, panel = NULL, xpanel = NULL, ypanel = NULL,
     	p <- p + coord_cartesian(ylim=axisYrange)
       }
       if (ci) {
-        qp$thresholdsci[[color]] <- factor(qp$thresholdsci[[color]])
-        p <- p + geom_errorbarh(data = qp$thresholdsci,
+        p <- p + geom_errorbarh(data = qp$thresholds,
                        height = .03, aes_string(x = 'threinf', xmin = 'threinf',
                        color = color, xmax = 'thresup', y = qp$thresholds$prob))
       }
@@ -162,7 +161,7 @@ plotcurves_ <- function(qp, panel = NULL, xpanel = NULL, ypanel = NULL,
       if (thresholds) p <- p + geom_linerange(data = qp$thresholds,
                         aes_string(x = 'thre', ymin = qp$guess,
                                ymax = qp$thresholds$prob))
-      if (ci) p <- p + geom_errorbarh(data = qp$thresholdsci,
+      if (ci) p <- p + geom_errorbarh(data = qp$thresholds,
                        height = .03, aes_string(x = 'threinf', xmin = 'threinf',
                        xmax = 'thresup', y = qp$thresholds$prob))
     }
