@@ -24,7 +24,7 @@
 #' @export
 plotthresholds <- function(qp, x = NULL, panel = NULL, xpanel = NULL,
                            ypanel = NULL, color = NULL, geom = 'bar', ci = T,
-                           sizeerrorbar = 1) {
+                           sizeerrorbar = .5) {
 
   if (!missing(x)) x <- deparse(substitute(x))
   if (!missing(panel)) panel <- deparse(substitute(panel))
@@ -32,5 +32,5 @@ plotthresholds <- function(qp, x = NULL, panel = NULL, xpanel = NULL,
   if (!missing(ypanel)) ypanel <- deparse(substitute(ypanel))
   if (!missing(color)) color <- deparse(substitute(color))
 
- plotthresholds_(qp, x, panel, xpanel, ypanel, color, geom, ci,sizeerrorbar)
+ plotthresholds_(qp, x, panel, xpanel, ypanel, color, geom, ci, sizeerrorbar)
 }
