@@ -66,8 +66,6 @@
 #' \code{guess + .5 * (1 - guess)}).
 #' @param thresholds If \code{FALSE}, thresholds are not calculated
 #' (default is \code{TRUE}).
-#' @param logliks If \code{TRUE}, the loglikelihoods are calculated
-#'  (default is \code{FALSE}).
 #' @param bootstrap \code{'parametric'} performs parametric bootstrap;
 #' \code{'nonparametric'} performs non-parametric bootstrap;
 #' \code{'none'} does not perform bootstrap (default is \code{'parametric'}).
@@ -98,12 +96,22 @@
 #'   \item \code{curvesbootstrap} Bootstrap curves.
 #'   \item \code{thresholds} Thresholds.
 #'   \item \code{thresholdsci} Confidence intervals for the thresholds.
+#'   \item \code{logliks} Log-likelihoods of the model.
+#'   \item \code{loglikssaturated} Log-likelihoods of the saturated model.
+#'   \item \code{deviance} Deviance of the model and the p-value calculated by
+#'    bootstraping.
+#'   \item \code{aic} AIC of the model defined as \deqn{ - 2 * loglik + 2  *k}
+#'   where k is the number of parameters of the model.
 #' }
 #' @references
+#' Burnham, K. P., & Anderson, D. R. (2003). Model selection and multimodel
+#' inference: a practical information-theoretic approach. Springer Science &
+#' Business Media.
+#'
 #' Knoblauch, K., & Maloney, L. T. (2012). Modeling Psychophysical Data in R.
 #' New York: Springer.
 #'
-#' Prins, N., & Kingdom, F. A. A. (2010). Psychophysics: a practical
+#' Prins, N., & Kingdom, F. A. A. (2016). Psychophysics: a practical
 #' introduction. London: Academic Press.
 #' @seealso \code{\link{quickpsy_}}
 #' @examples
@@ -115,6 +123,7 @@
 #' plotcurves(fit)
 #' plotpar(fit)
 #' plotthresholds(fit, geom = 'point')
+
 #' @export
 #' @import MPDiR
 #' @importFrom  graphics par
@@ -122,11 +131,10 @@
 #' quantile qweibull rbinom
 #' @importFrom utils combn head read.table tail
 
-
 quickpsy <- function(d, x = x, k = k, n = n, grouping, random, within, between,
                      xmin = NULL, xmax = NULL, log = FALSE,
                      fun = cum_normal_fun, parini = NULL, guess = 0, lapses = 0,
-                     prob = NULL, thresholds = T, logliks = FALSE,
+                     prob = NULL, thresholds = T,
                      bootstrap = 'parametric', B = 100, ci = .95,
                      optimization = 'optim') {
 
@@ -143,7 +151,7 @@ quickpsy <- function(d, x = x, k = k, n = n, grouping, random, within, between,
 
   ### calling the standard evaluation of quickpsy
   quickpsy_(d, x, k, n, grouping, random, within, between, xmin, xmax, log, fun,
-            parini, guess, lapses, prob, thresholds, logliks, bootstrap,
+            parini, guess, lapses, prob, thresholds, bootstrap,
             B, ci, optimization)
 }
 
